#!/usr/bin/env python

"""
Copying utilities.

Copyright (C) 2019 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from shutil import copy

def copy_attachments(parser, input, output):

    "Copy attachments referenced by 'parser' from 'input' to 'output'."

    pagename = parser.metadata.get("pagename")

    if not pagename:
        return

    for link_target in parser.link_targets:

        # Obtain attachments.

        if link_target.get_type() == "attachment":

            # Obtain the attachment filename, the source location and the
            # destination.

            filename = link_target.get_identifier()
            input_filename = input.get_attachment_filename(pagename, filename)
            output_filename = output.get_attachment_filename(pagename, filename)

            # Copy the file if possible.

            if input_filename and output_filename:
                output.ensure_attachments(pagename)
                copy(input_filename, output_filename)

# vim: tabstop=4 expandtab shiftwidth=4
